/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief Example project on GPIO usage to drive LEDs
* @defgroup gpio_example GPIO example
* @{
* @ingroup nrf_examples_nrf6310
*
* @brief Example of GPIO output usage.
*
* This example shows how to configure GPIO pins as outputs which can also be used to drive LEDs.
* Each LED is set on one at a time and each state lasts 100 milliseconds.
* @image html example_board_setup_a.png "Use setup A when using the nrf6310 board for this example."
*/

#include <stdbool.h>
#include <stdint.h>
#include "nrf_delay.h"
#include "nrf_gpio.h"
#include "boards.h"

typedef enum
{
	POWER_THRESHOLD_2_1V = 0,
	POWER_THRESHOLD_2_3V = 1,
	POWER_THRESHOLD_2_5V = 2,
	POWER_THRESHOLD_2_7V = 3 
} power_pofcon_threshold_t;

volatile bool pof_fired = false;

void POWER_CLOCK_IRQHandler(void)
{
	if(NRF_POWER->EVENTS_POFWARN != 0)
	{
		NRF_POWER->EVENTS_POFWARN = 0;
		/* Power warning! */
		pof_fired = true;
	}
}

void set_pofcon_threshold(power_pofcon_threshold_t pof_thresh)
{
	NRF_POWER->POFCON = (pof_thresh << POWER_POFCON_THRESHOLD_Pos);
	NRF_POWER->POFCON = (POWER_POFCON_POF_Enabled << POWER_POFCON_POF_Pos);
	NRF_POWER->INTENSET = (POWER_INTENCLR_POFWARN_Enabled << POWER_INTENSET_POFWARN_Pos);	
	NVIC_EnableIRQ(POWER_CLOCK_IRQn);
}

/**
 * main() function
 * @return 0. int return type required by ANSI/ISO standard.
 */
int main(void)
{
	set_pofcon_threshold(POWER_THRESHOLD_2_7V);
	NRF_GPIO->DIRSET = 3;
	NRF_GPIO->OUT |= 2; 
  while(true)
  {
		if (pof_fired)// || NRF_POWER->EVENTS_POFWARN)
		{		
			NRF_GPIO->OUT |=  1;
        }
        __WFI();
  }
}

/**
 *@}
 **/
